.. _componentlists:

Component Lists
===============

Weblate allows you to specify multiple lists of components. These will then
appear as options on the user dashboard, and users can pick a list to be their
default view when they log in. See :ref:`dashboard` to learn more about this
feature.

The names and contents of component lists can be specified in the admin
interface, in :guilabel:`Component lists` section. Each component list must
have a name that is displayed to the user, and a slug that represents it in the
URL.
